#!/bin/sh

# Script to upgrade PostgreSQL & PostGIS on a default Debian Wheezy
# - part 1

# Update system
apt-get update
apt-get upgrade -y
apt-get clean

# Backup
su postgres
pg_dump -Fc gis > gis.dump
pg_dump -Fc sahana > sahana.dump
exit

# Upgrade PostgreSQL
apt-get -y install python-software-properties
wget --quiet -O - http://apt.postgresql.org/pub/repos/apt/ACCC4CF8.asc | sudo apt-key add -
add-apt-repository "deb http://apt.postgresql.org/pub/repos/apt/ wheezy-pgdg main"
apt-get update
apt-get install postgresql-9.3 postgresql-client-9.3 postgresql-server-dev-9.3
/etc/init.d/uwsgi stop
/etc/init.d/uwsgi-prod stop
/etc/init.d/uwsgi-demo stop
/etc/init.d/uwsgi-test stop
su postgres
pg_dropcluster --stop 9.3 main    
pg_upgradecluster 9.1 main

# Upgrade PostGIS
apt-get install -y postgresql-9.3-postgis

# Hard-upgrade Data
cd ..
su postgres
dropdb gis
dropdb sahana
createdb -O gis -E UTF8 gis -T template0
createdb -O sahana -E UTF8 sahana -T template0
su -c - postgres "psql -q -d sahana -f /usr/share/postgresql/9.3/extension/postgis--2.1.1.sql"
su -c - postgres "psql -q -d sahana -c 'grant all on geometry_columns to sahana;'"
su -c - postgres "psql -q -d sahana -c 'grant all on spatial_ref_sys to sahana;'"
perl /usr/share/postgresql/9.3/contrib/postgis-2.1/postgis_restore.pl gis.dump | psql gis
perl /usr/share/postgresql/9.3/contrib/postgis-2.1/postgis_restore.pl sahana.dump | psql sahana

# Upgrade management scripts
sed -i 's/9.1/9.3/g' /usr/local/bin/clean
sed -i 's/1.5/2.1/g' /usr/local/bin/clean

cat << EOF > "/usr/local/bin/pg1024"
#!/bin/sh
sed -i 's|kernel.shmmax = 279134208|#kernel.shmmax = 279134208|' /etc/sysctl.conf
sed -i 's|#kernel.shmmax = 552992768|kernel.shmmax = 552992768|' /etc/sysctl.conf
sysctl -w kernel.shmmax=552992768
sed -i 's|shared_buffers = 56MB|shared_buffers = 160MB|' /etc/postgresql/9.3/main/postgresql.conf
sed -i 's|effective_cache_size = 256MB|effective_cache_size = 512MB|' /etc/postgresql/9.3/main/postgresql.conf
sed -i 's|work_mem = 2MB|work_mem = 4MB|' /etc/postgresql/9.3/main/postgresql.conf
/etc/init.d/postgresql restart
EOF
chmod +x /usr/local/bin/pg1024

cat << EOF > "/usr/local/bin/pg512"
#!/bin/sh
sed -i 's|#kernel.shmmax = 279134208|kernel.shmmax = 279134208|' /etc/sysctl.conf
sed -i 's|kernel.shmmax = 552992768|#kernel.shmmax = 552992768|' /etc/sysctl.conf
sysctl -w kernel.shmmax=279134208
sed -i 's|shared_buffers = 160MB|shared_buffers = 56MB|' /etc/postgresql/9.3/main/postgresql.conf
sed -i 's|effective_cache_size = 512MB|effective_cache_size = 256MB|' /etc/postgresql/9.3/main/postgresql.conf
sed -i 's|work_mem = 4MB|work_mem = 2MB|' /etc/postgresql/9.3/main/postgresql.conf
/etc/init.d/postgresql restart
EOF
chmod +x /usr/local/bin/pg512

echo 'Test after reboot - and then run part2'

# END
